@@ -1295,6 +1295,36 @@ EOH
 };
 
 
+=head2 Genreport resources
+
+=cut
+
+$defs->{'genreport'} = {
+
+    # /genreport
+    'genreport' => 
+    {
+        parent => '/',
+        handler => {
+            GET => 'handler_noop',
+            POST => 'handler_genreport',
+        },
+        acl_profile => {
+            GET => 'passerby',
+            POST => 'admin',
+        },
+        cli => 'genreport',
+        description => 'Generate reports',
+        documentation => <<'EOH',
+=pod
+
+Generate reports.
+EOH
+    },
+
+};
+
+
 =head2 History resources
 
 =cut
@@ -2753,7 +2783,8 @@ Load all the resource definitions into the L<Path::Router> instance.
 =cut
 
 sub load {
-    foreach my $prop ( qw( top activity component employee history interval lock priv schedule ) ) {
+    foreach my $prop ( qw( top activity component employee genreport
+                           history interval lock priv schedule ) ) {
         Web::MREST::InitRouter::load_resource_defs( $defs->{$prop} ) if $defs->{$prop};
     }
 }
